MultiTrainingCallback
=====================

.. currentmodule:: pykeen.training.callbacks

.. autoclass:: MultiTrainingCallback
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MultiTrainingCallback.on_batch
      ~MultiTrainingCallback.post_batch
      ~MultiTrainingCallback.post_epoch
      ~MultiTrainingCallback.post_train
      ~MultiTrainingCallback.register_callback
      ~MultiTrainingCallback.register_training_loop

   .. rubric:: Methods Documentation

   .. automethod:: on_batch
   .. automethod:: post_batch
   .. automethod:: post_epoch
   .. automethod:: post_train
   .. automethod:: register_callback
   .. automethod:: register_training_loop
